@@ -20,7 +20,21 @@
 #ifndef _ArcBall_h
 #define _ArcBall_h
 
-#include "math.h"                                               // Needed for sqrtf
+#include <QtGlobal>
+
+#ifdef Q_OS_MAC
+#include <OpenGL/gl.h>
+#include <OpenGL/glu.h>
+#elif defined(Q_OS_WIN)
+#include <windows.h>
+#include <GL/gl.h>                                                                                             // Header File For The OpenGL32 Library
+#include <GL/glu.h>                                                                                            // Header File For The GLu32 Library
+#else
+#include <GL/gl.h>                                                                                             // Header File For The OpenGL32 Library
+#include <GL/glu.h>                                                                                            // Header File For The GLu32 Library
+#endif
+
+#include <math.h>                                               // Needed for sqrtf
 
 // 8<--Snip here if you have your own math types/funcs-->8 
 
@@ -31,18 +45,6 @@
 # define assert(x) { }
 #endif
 
-#ifdef Q_OS_MAC
-#include <OpenGL/gl.h>
-#include <OpenGL/glu.h>
-#elif defined(Q_WS_WIN)
-#include <windows.h>
-#include <GL/gl.h>                                                                                             // Header File For The OpenGL32 Library
-#include <GL/glu.h>                                                                                            // Header File For The GLu32 Library
-#else
-#include <GL/gl.h>                                                                                             // Header File For The OpenGL32 Library
-#include <GL/glu.h>                                                                                            // Header File For The GLu32 Library
-#endif
-
 //Math types derived from the KempoApi tMath library
     typedef union Tuple2f_t
     {
